@@ -134,6 +134,34 @@ class TestClientRequest(unittest.TestCase):
                u'key': u'/testkey',
                u'value': u'test'}), result)
 
+    def test_get_multi(self):
+        """Can get multiple values"""
+        client = etcd.Client()
+        client.api_execute = mock.Mock(
+            return_value =
+            '[{"action":"GET",'
+            '"key":"/testdir/key1",'
+            '"value":"test1",'
+            '"index":190},'
+            '{"action":"GET",'
+            '"key":"/testdir/key2",'
+            '"value":"test2",'
+            '"index":190}]'
+        )
+        result = client.get('/testdir')
+        self.assertEquals([
+            etcd.EtcdResult(
+            **{u'action': u'GET',
+               u'index': 190,
+               u'key': u'/testdir/key1',
+               u'value': u'test1'}),
+            etcd.EtcdResult(
+            **{u'action': u'GET',
+               u'index': 190,
+               u'key': u'/testdir/key2',
+               u'value': u'test2'})
+        ], result)
+
     def test_not_in(self):
         """ Can check if key is not in client """
         client = etcd.Client()
